@@ -8,13 +8,15 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2017 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2018 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //============================================================================
 
+#include "Debugger.hxx"
+#include "CartDebug.hxx"
 #include "CartCTY.hxx"
 #include "PopUpWidget.hxx"
 #include "CartCTYWidget.hxx"
@@ -62,12 +64,13 @@ void CartridgeCTYWidget::saveOldState()
   {
     myOldState.internalram.push_back(myCart.myRAM[i]);
   }
+  myOldState.bank = myCart.getBank();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void CartridgeCTYWidget::loadConfig()
 {
-  myBank->setSelectedIndex(myCart.getBank()-1);
+  myBank->setSelectedIndex(myCart.getBank()-1, myCart.getBank() != myOldState.bank);
 
   CartDebugWidget::loadConfig();
 }
