@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2017 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2018 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -20,6 +20,9 @@
 #include "DiStella.hxx"
 #include "PackedBitArray.hxx"
 #include "Widget.hxx"
+#include "StellaKeys.hxx"
+#include "FBSurface.hxx"
+#include "Font.hxx"
 #include "ScrollBarWidget.hxx"
 #include "RomListSettings.hxx"
 #include "RomListWidget.hxx"
@@ -64,10 +67,10 @@ RomListWidget::RomListWidget(GuiObject* boss, const GUI::Font& lfont,
   const int fontWidth = lfont.getMaxCharWidth(),
             numchars = w / fontWidth;
 
-  _labelWidth = std::max(16, int(0.20 * (numchars - 12))) * fontWidth - 1;
-  _bytesWidth = 12 * fontWidth;
+  _labelWidth = std::max(14, int(0.45 * (numchars - 8 - 8 - 9 - 2))) * fontWidth - 1;
+  _bytesWidth = 9 * fontWidth;
 
-  //////////////////////////////////////////////////////
+  ///////////////////////////////////////////////////////
   // Add checkboxes
   int ypos = _y + 2;
 
@@ -80,7 +83,8 @@ RomListWidget::RomListWidget(GuiObject* boss, const GUI::Font& lfont,
   CheckboxWidget* t = nullptr;
   for(int i = 0; i < _rows; ++i)
   {
-    t = new CheckboxWidget(boss, lfont, _x + 2, ypos, "", kCheckActionCmd);
+    t = new CheckboxWidget(boss, lfont, _x + 2, ypos, "",
+                           CheckboxWidget::kCheckActionCmd);
     t->setTarget(this);
     t->setID(i);
     t->setFill(CheckboxWidget::Circle);
@@ -114,7 +118,6 @@ RomListWidget::RomListWidget(GuiObject* boss, const GUI::Font& lfont,
       default:  // TODO - properly handle all other cases
         return false;
     }
-    return false;
   };
   setTextFilter(f);
 }
@@ -235,13 +238,13 @@ void RomListWidget::scrollToCurrent(int item)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void RomListWidget::handleMouseDown(int x, int y, int button, int clickCount)
+void RomListWidget::handleMouseDown(int x, int y, MouseButton b, int clickCount)
 {
   if (!isEnabled())
     return;
 
   // Grab right mouse button for context menu, left for selection/edit mode
-  if(button == 2)
+  if(b == MouseButton::RIGHT)
   {
     // Set selected and add menu at current x,y mouse location
     _selectedItem = findItem(x, y);
@@ -267,7 +270,7 @@ void RomListWidget::handleMouseDown(int x, int y, int button, int clickCount)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void RomListWidget::handleMouseUp(int x, int y, int button, int clickCount)
+void RomListWidget::handleMouseUp(int x, int y, MouseButton b, int clickCount)
 {
   // If this was a double click and the mouse is still over the selected item,
   // send the double click command
@@ -300,7 +303,7 @@ bool RomListWidget::handleText(char text)
 bool RomListWidget::handleKeyDown(StellaKey key, StellaMod mod)
 {
   // Ignore all Alt-mod keys
-  if(instance().eventHandler().kbdAlt(mod))
+  if(StellaModTest::isAlt(mod))
     return true;
 
   bool handled = true;
@@ -414,14 +417,14 @@ void RomListWidget::handleCommand(CommandSender* sender, int cmd, int data, int
 {
   switch (cmd)
   {
-    case kCheckActionCmd:
+    case CheckboxWidget::kCheckActionCmd:
       // We let the parent class handle this
       // Pass it as a kRLBreakpointChangedCmd command, since that's the intent
       sendCommand(RomListWidget::kBPointChangedCmd, _currentPos+id,
                   myCheckList[id]->getState());
       break;
 
-    case kSetPositionCmd:
+    case GuiObject::kSetPositionCmd:
       if (_currentPos != data)
       {
         _currentPos = data;
@@ -461,17 +464,19 @@ void RomListWidget::drawWidget(bool hilite)
   s.vLine(_x + CheckboxWidget::boxSize() + 5, _y, _y + _h - 1, kColor);
 
   // Draw the list items
-  int ccountw = _fontWidth << 2,
-      large_disasmw = _w - l.x() - _labelWidth,
-      medium_disasmw = large_disasmw - r.width(),
-      small_disasmw = medium_disasmw - (ccountw << 1),
-      actualwidth = myDisasm->fieldwidth * _fontWidth;
-  if(actualwidth < small_disasmw)
-    small_disasmw = actualwidth;
+  int cycleCountW = _fontWidth * 8,
+      noTypeDisasmW = _w - l.x() - _labelWidth,
+      noCodeDisasmW = noTypeDisasmW - r.width(),
+      codeDisasmW = noCodeDisasmW - cycleCountW,
+      actualWidth = myDisasm->fieldwidth * _fontWidth;
+  if(actualWidth < codeDisasmW)
+    codeDisasmW = actualWidth;
 
   xpos = _x + CheckboxWidget::boxSize() + 10;  ypos = _y + 2;
   for (i = 0, pos = _currentPos; i < _rows && pos < len; i++, pos++, ypos += _fontHeight)
   {
+    uInt32 bytesColor = kTextColor;
+
     // Draw checkboxes for correct lines (takes scrolling into account)
     myCheckList[i]->setState(myBPState->isSet(dlist[pos].address));
     myCheckList[i]->setDirty();
@@ -482,10 +487,13 @@ void RomListWidget::drawWidget(bool hilite)
       s.frameRect(_x + l.x() - 3, ypos - 1, _w - l.x(), _fontHeight, kTextColorHi);
 
     // Draw the selected item inverted, on a highlighted background.
-    if (_selectedItem == pos && _hasFocus)
+    if(_selectedItem == pos && _hasFocus)
     {
-      if (!_editMode)
+      if(!_editMode)
+      {
         s.fillRect(_x + r.x() - 3, ypos - 1, r.width(), _fontHeight, kTextColorHi);
+        bytesColor = kTextColorInv;
+      }
       else
         s.frameRect(_x + r.x() - 3, ypos - 1, r.width(), _fontHeight, kTextColorHi);
     }
@@ -500,17 +508,22 @@ void RomListWidget::drawWidget(bool hilite)
     {
       if(dlist[pos].type == CartDebug::CODE)
       {
-        // Draw disassembly and cycle count
-        s.drawString(_font, dlist[pos].disasm, xpos + _labelWidth, ypos,
-                     small_disasmw, kTextColor);
-        s.drawString(_font, dlist[pos].ccount, xpos + _labelWidth + small_disasmw, ypos,
-                     ccountw, kTextColor);
+        // Draw mnemonic
+        s.drawString(_font, dlist[pos].disasm.substr(0, 7), xpos + _labelWidth, ypos,
+                     7 * _fontWidth, kTextColor);
+        // Draw operand
+        if (dlist[pos].disasm.length() > 8)
+          s.drawString(_font, dlist[pos].disasm.substr(8), xpos + _labelWidth + 7 * _fontWidth, ypos,
+                       codeDisasmW - 7 * _fontWidth, kTextColor);
+        // Draw cycle count
+        s.drawString(_font, dlist[pos].ccount, xpos + _labelWidth + codeDisasmW, ypos,
+                     cycleCountW, kTextColor);
       }
       else
       {
         // Draw disassembly only
         s.drawString(_font, dlist[pos].disasm, xpos + _labelWidth, ypos,
-                     medium_disasmw, kTextColor);
+                     noCodeDisasmW - 4, kTextColor);
       }
 
       // Draw separator
@@ -522,13 +535,13 @@ void RomListWidget::drawWidget(bool hilite)
         {
           adjustOffset();
           s.drawString(_font, editString(), _x + r.x(), ypos, r.width(), kTextColor,
-                       kTextAlignLeft, -_editScrollOffset, false);
+                       TextAlign::Left, -_editScrollOffset, false);
 
           drawCaret();
         }
         else
         {
-          s.drawString(_font, dlist[pos].bytes, _x + r.x(), ypos, r.width(), kTextColor);
+          s.drawString(_font, dlist[pos].bytes, _x + r.x(), ypos, r.width(), bytesColor);
         }
       }
     }
@@ -536,7 +549,7 @@ void RomListWidget::drawWidget(bool hilite)
     {
       // Draw disassembly, giving it all remaining horizontal space
       s.drawString(_font, dlist[pos].disasm, xpos + _labelWidth, ypos,
-                   large_disasmw, kTextColor);
+                   noTypeDisasmW, kTextColor);
     }
   }
 }
@@ -582,7 +595,7 @@ void RomListWidget::startEditMode()
     {
       case CartDebug::GFX:
       case CartDebug::PGFX:
-        _base = DiStella::settings.gfx_format;
+        _base = DiStella::settings.gfxFormat;
         break;
       default:
         _base = Common::Base::format();
