@@ -8,14 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2017 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2018 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //============================================================================
 
-#include "MT24LC256.hxx"
 #include "SerialPort.hxx"
 #include "System.hxx"
 #include "AtariVox.hxx"
@@ -24,7 +23,7 @@
 AtariVox::AtariVox(Jack jack, const Event& event, const System& system,
                    const SerialPort& port, const string& portname,
                    const string& eepromfile)
-  : Controller(jack, event, system, Controller::AtariVox),
+  : SaveKey(jack, event, system, eepromfile, Controller::AtariVox),
     mySerialPort(const_cast<SerialPort&>(port)),
     myShiftCount(0),
     myShiftRegister(0),
@@ -35,9 +34,6 @@ AtariVox::AtariVox(Jack jack, const Event& event, const System& system,
   else
     myAboutString = " (invalid serial port \'" + portname + "\')";
 
-  myEEPROM = make_unique<MT24LC256>(eepromfile, system);
-
-  myDigitalPinState[One] = myDigitalPinState[Two] =
   myDigitalPinState[Three] = myDigitalPinState[Four] = true;
 }
 
@@ -54,13 +50,8 @@ bool AtariVox::read(DigitalPin pin)
       // For now, we just assume the device is always ready
       return myDigitalPinState[Two] = true;
 
-    // Pin 3: EEPROM SDA
-    //        input data from the 24LC256 EEPROM using the I2C protocol
-    case Three:
-      return myDigitalPinState[Three] = myEEPROM->readSDA();
-
     default:
-      return Controller::read(pin);
+      return SaveKey::read(pin);
   }
 }
 
@@ -77,35 +68,20 @@ void AtariVox::write(DigitalPin pin, bool value)
       clockDataIn(value);
       break;
 
-    // Pin 3: EEPROM SDA
-    //        output data to the 24LC256 EEPROM using the I2C protocol
-    case Three:
-      myDigitalPinState[Three] = value;
-      myEEPROM->writeSDA(value);
-      break;
-
-    // Pin 4: EEPROM SCL
-    //        output clock data to the 24LC256 EEPROM using the I2C protocol
-    case Four:
-      myDigitalPinState[Four] = value;
-      myEEPROM->writeSCL(value);
-      break;
-
     default:
-      break;
+      SaveKey::write(pin, value);
   }
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void AtariVox::clockDataIn(bool value)
 {
-  uInt32 cycle = mySystem.cycles();
-
   if(value && (myShiftCount == 0))
     return;
 
   // If this is the first write this frame, or if it's been a long time
   // since the last write, start a new data byte.
+  uInt64 cycle = mySystem.cycles();
   if((cycle < myLastDataWriteCycle) || (cycle > myLastDataWriteCycle + 1000))
   {
     myShiftRegister = 0;
@@ -139,24 +115,8 @@ void AtariVox::clockDataIn(bool value)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void AtariVox::close()
+void AtariVox::reset()
 {
-  // Force the EEPROM object to cleanup
-  myEEPROM.reset();
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void AtariVox::systemCyclesReset()
-{
-  myLastDataWriteCycle -= mySystem.cycles();
-
-  // The EEPROM keeps track of cycle counts, and needs to know when the
-  // cycles are reset
-  myEEPROM->systemCyclesReset();
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-string AtariVox::about() const
-{
-  return Controller::about() + myAboutString;
+  myLastDataWriteCycle = 0;
+  SaveKey::reset();
 }
