@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2017 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2018 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -16,9 +16,12 @@
 //============================================================================
 
 #include "OSystem.hxx"
+#include "FrameBuffer.hxx"
+#include "EventHandler.hxx"
 #include "Dialog.hxx"
 #include "DialogContainer.hxx"
 #include "Widget.hxx"
+#include "Font.hxx"
 #include "Control.hxx"
 #include "VideoDialog.hxx"
 #include "AudioDialog.hxx"
@@ -29,6 +32,7 @@
 #include "RomAuditDialog.hxx"
 #include "GameInfoDialog.hxx"
 #include "LoggerDialog.hxx"
+#include "DeveloperDialog.hxx"
 #include "HelpDialog.hxx"
 #include "AboutDialog.hxx"
 #include "OptionsDialog.hxx"
@@ -42,12 +46,12 @@
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 OptionsDialog::OptionsDialog(OSystem& osystem, DialogContainer& parent,
-                             GuiObject* boss, int max_w, int max_h, bool global)
+                             GuiObject* boss, int max_w, int max_h, stellaMode mode)
   : Dialog(osystem, parent),
-    myIsGlobal(global)
+    myMode(mode)
 {
   const GUI::Font& font = instance().frameBuffer().font();
-  const int buttonWidth = font.getStringWidth("Snapshot Settings") + 20,
+  const int buttonWidth = font.getStringWidth("Developer Settings" + ELLIPSIS) + 20,
             buttonHeight = font.getLineHeight() + 6,
             rowHeight = font.getLineHeight() + 10;
 
@@ -66,49 +70,52 @@ OptionsDialog::OptionsDialog(OSystem& osystem, DialogContainer& parent,
     return bw;
   };
 
-  b = ADD_OD_BUTTON("Video Settings", kVidCmd);
+  b = ADD_OD_BUTTON("Video Settings" + ELLIPSIS, kVidCmd);
   wid.push_back(b);
 
-  b = ADD_OD_BUTTON("Audio Settings", kAudCmd);
+  b = ADD_OD_BUTTON("Audio Settings" + ELLIPSIS, kAudCmd);
 #ifndef SOUND_SUPPORT
   b->clearFlags(WIDGET_ENABLED);
 #endif
   wid.push_back(b);
 
-  b = ADD_OD_BUTTON("Input Settings", kInptCmd);
+  b = ADD_OD_BUTTON("Input Settings" + ELLIPSIS, kInptCmd);
   wid.push_back(b);
 
-  b = ADD_OD_BUTTON("UI Settings", kUsrIfaceCmd);
+  b = ADD_OD_BUTTON("UI Settings" + ELLIPSIS, kUsrIfaceCmd);
   wid.push_back(b);
 
-  b = ADD_OD_BUTTON("Snapshot Settings", kSnapCmd);
+  b = ADD_OD_BUTTON("Snapshot Settings" + ELLIPSIS, kSnapCmd);
   wid.push_back(b);
 
-  b = ADD_OD_BUTTON("Config Paths", kCfgPathsCmd);
+  b = ADD_OD_BUTTON("Config Paths" + ELLIPSIS, kCfgPathsCmd);
   wid.push_back(b);
 
-  myRomAuditButton = ADD_OD_BUTTON("Audit ROMs", kAuditCmd);
-  wid.push_back(myRomAuditButton);
+  b = ADD_OD_BUTTON("Developer Settings" + ELLIPSIS, kDevelopCmd);
+  wid.push_back(b);
 
   // Move to second column
   xoffset += buttonWidth + 10;  yoffset = 10;
 
-  myGameInfoButton = ADD_OD_BUTTON("Game Properties", kInfoCmd);
+  myGameInfoButton = ADD_OD_BUTTON("Game Properties" + ELLIPSIS, kInfoCmd);
   wid.push_back(myGameInfoButton);
 
-  myCheatCodeButton = ADD_OD_BUTTON("Cheat Code", kCheatCmd);
+  myCheatCodeButton = ADD_OD_BUTTON("Cheat Code" + ELLIPSIS, kCheatCmd);
 #ifndef CHEATCODE_SUPPORT
   myCheatCodeButton->clearFlags(WIDGET_ENABLED);
 #endif
   wid.push_back(myCheatCodeButton);
 
-  b = ADD_OD_BUTTON("System Logs", kLoggerCmd);
+  myRomAuditButton = ADD_OD_BUTTON("Audit ROMs" + ELLIPSIS, kAuditCmd);
+  wid.push_back(myRomAuditButton);
+
+  b = ADD_OD_BUTTON("System Logs" + ELLIPSIS, kLoggerCmd);
   wid.push_back(b);
 
-  b = ADD_OD_BUTTON("Help", kHelpCmd);
+  b = ADD_OD_BUTTON("Help" + ELLIPSIS, kHelpCmd);
   wid.push_back(b);
 
-  b = ADD_OD_BUTTON("About", kAboutCmd);
+  b = ADD_OD_BUTTON("About" + ELLIPSIS, kAboutCmd);
   wid.push_back(b);
 
   b = ADD_OD_BUTTON("Exit Menu", kExitCmd);
@@ -116,7 +123,7 @@ OptionsDialog::OptionsDialog(OSystem& osystem, DialogContainer& parent,
   addCancelWidget(b);
 
   // Now create all the dialogs attached to each menu button
-  myVideoDialog    = make_unique<VideoDialog>(osystem, parent, font, max_w, max_h, myIsGlobal);
+  myVideoDialog    = make_unique<VideoDialog>(osystem, parent, font, max_w, max_h);
   myAudioDialog    = make_unique<AudioDialog>(osystem, parent, font);
   myInputDialog    = make_unique<InputDialog>(osystem, parent, font, max_w, max_h);
   myUIDialog       = make_unique<UIDialog>(osystem, parent, font);
@@ -128,13 +135,14 @@ OptionsDialog::OptionsDialog(OSystem& osystem, DialogContainer& parent,
   myCheatCodeDialog = make_unique<CheatCodeDialog>(osystem, parent, font);
 #endif
   myLoggerDialog    = make_unique<LoggerDialog>(osystem, parent, font, max_w, max_h);
+  myDeveloperDialog = make_unique<DeveloperDialog>(osystem, parent, font, max_w, max_h);
   myHelpDialog      = make_unique<HelpDialog>(osystem, parent, font);
   myAboutDialog     = make_unique<AboutDialog>(osystem, parent, font);
 
   addToFocusList(wid);
 
   // Certain buttons are disabled depending on mode
-  if(myIsGlobal)
+  if(myMode == launcher)
   {
     myCheatCodeButton->clearFlags(WIDGET_ENABLED);
   }
@@ -144,6 +152,11 @@ OptionsDialog::OptionsDialog(OSystem& osystem, DialogContainer& parent,
   }
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+OptionsDialog::~OptionsDialog()
+{
+}
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void OptionsDialog::loadConfig()
 {
@@ -152,10 +165,10 @@ void OptionsDialog::loadConfig()
   // in launcher mode
   switch(instance().eventHandler().state())
   {
-    case EventHandler::S_EMULATE:
+    case EventHandlerState::EMULATION:
       myGameInfoButton->setFlags(WIDGET_ENABLED);
       break;
-    case EventHandler::S_LAUNCHER:
+    case EventHandlerState::LAUNCHER:
       if(instance().launcher().selectedRomMD5() != "")
         myGameInfoButton->setFlags(WIDGET_ENABLED);
       else
@@ -213,7 +226,7 @@ void OptionsDialog::handleCommand(CommandSender* sender, int cmd,
     case kLoggerCmd:
       // This dialog is resizable under certain conditions, so we need
       // to re-create it as necessary
-      if(!myIsGlobal)
+      if(myMode != launcher)
       {
         uInt32 w = 0, h = 0;
         bool uselargefont = getResizableBounds(w, h);
@@ -224,6 +237,10 @@ void OptionsDialog::handleCommand(CommandSender* sender, int cmd,
       myLoggerDialog->open();
       break;
 
+    case kDevelopCmd:
+      myDeveloperDialog->open();
+      break;
+
     case kHelpCmd:
       myHelpDialog->open();
       break;
@@ -233,7 +250,7 @@ void OptionsDialog::handleCommand(CommandSender* sender, int cmd,
       break;
 
     case kExitCmd:
-      if(myIsGlobal)
+      if(myMode != emulator)
         close();
       else
         instance().eventHandler().leaveMenuMode();
