@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2017 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2018 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -35,7 +35,7 @@ OSystemUNIX::OSystemUNIX()
 {
   // Use XDG_CONFIG_HOME if defined, otherwise use the default
   const char* configDir = getenv("XDG_CONFIG_HOME");
-  if(configDir == NULL)  configDir = "~/.config";
+  if(configDir == nullptr)  configDir = "~/.config";
 
   string stellaDir = string(configDir) + "/stella";
 
